#!/usr/bin/env python
# coding: utf-8

# ### The goal of this notebook is find material systems with high melting point, high ITR. 4 different models was used to make the predictions: KRR, XGB and DNN. 

# In[1]:


import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import math
import time
import random
import torch
from sklearn.model_selection import train_test_split, GridSearchCV
from sklearn.metrics import mean_squared_error
from sklearn.model_selection import KFold
from sklearn.metrics import r2_score
from sklearn.gaussian_process import GaussianProcessRegressor
from sklearn.gaussian_process.kernels import RBF, ConstantKernel as ConstantKernel
from sklearn.kernel_ridge import KernelRidge
from sklearn.neighbors import KNeighborsRegressor
from sklearn.decomposition import PCA
from sklearn.ensemble import RandomForestRegressor
from sklearn.preprocessing import StandardScaler
from sklearn.preprocessing import minmax_scale


# # Load data

# In[2]:


ms_ITR = pd.read_excel('ms_ITR_600K_20210626.xlsx')
top = 1000


# # Material system properties

# ## High melting point, high ITR

# ## KRR model

# In[3]:


# Rank the ms_ITR entries by krr_ITR and select top x. 
ms_ITR['krr_rank'] = ms_ITR['krr_ITR'].rank()
ms_ITR.sort_values('krr_ITR', ascending=False,inplace=True)
data1 = ms_ITR[:top]
data1
print(data1['fmelt'].describe())
print(data1['smelt'].describe())

# Further filter out high melting poing material systems with fmelt and smelt > 600 K
krr_high_mp = data1.loc[(data1['fmelt'] >= 600) & (data1['smelt'] >= 600)]
krr_high_mp_index = krr_high_mp.index
krr_high_mp.to_excel('krr_high_mp_600K_20210626.xlsx')

#Select the top 100 ITR ranked by KRR model. This is used to compare with literature models
krr_high_ITR = ms_ITR[:100]
krr_high_ITR.to_excel('krr_high_ITR_600K_20210626.xlsx')
krr_high_ITR_index = krr_high_ITR.index
print('Done!')


# ## XGB model

# In[4]:


# Rank the ms_ITR entries by xgb_ITR and select top x. 
ms_ITR['xgb_rank'] = ms_ITR['xgb_ITR'].rank()
ms_ITR.sort_values('xgb_ITR', ascending=False,inplace=True)
data1 = ms_ITR[:top]
data1
print(data1['fmelt'].describe())
print(data1['smelt'].describe())

# Further filter out high melting poing material systems with fmelt and smelt > 600 K
xgb_high_mp = data1.loc[(data1['fmelt'] >= 600) & (data1['smelt'] >= 600)]
xgb_high_mp_index = xgb_high_mp.index
xgb_high_mp.to_excel('xgb_high_mp_600K_20210626.xlsx')

#Select the top 100 ITR ranked by xgb model. This is used to compare with literature models
xgb_high_ITR = ms_ITR[:100]
xgb_high_ITR.to_excel('xgb_high_ITR_600K_20210626.xlsx')
xgb_high_ITR_index = xgb_high_ITR.index
print('Done!')


# ## DNN model

# In[5]:


# Rank the ms_ITR entries by dnn_ITR and select top x. 
ms_ITR['dnn_rank'] = ms_ITR['dnn_ITR'].rank()
ms_ITR.sort_values('dnn_ITR', ascending=False,inplace=True)
data2 = ms_ITR[:top]
print(data2['fmelt'].describe())
print(data2['smelt'].describe())

# Further filter out high melting poing material systems with fmelt and smelt > 600 K
dnn_high_mp = data2.loc[(data2['fmelt'] >= 600) & (data2['smelt'] >= 600)]
dnn_high_mp_index = dnn_high_mp.index
# print(type(dnn_high_mp_index))
dnn_high_mp.to_excel('dnn_high_mp_600K_20210626.xlsx')

#Select the top 100 ITR ranked by xgb model. This is used to compare with literature models
dnn_high_ITR = ms_ITR[:100]
dnn_high_ITR.to_excel('dnn_high_ITR_600K_20210626.xlsx')
dnn_high_ITR_index = dnn_high_ITR.index
print('Done!')


# ## Ensemble model

# In[6]:


# Rank the ms_ITR entries by en_ITR and select top x. 
ms_ITR['en_rank'] = ms_ITR['en_ITR'].rank()
ms_ITR.sort_values('en_ITR', ascending=False,inplace=True)
data1 = ms_ITR[:top]
data1
print(data1['fmelt'].describe())
print(data1['smelt'].describe())

# Further filter out high melting poing material systems with fmelt and smelt > 600 K
en_high_mp = data1.loc[(data1['fmelt'] >= 600) & (data1['smelt'] >= 600)]
en_high_mp_index = en_high_mp.index
en_high_mp.to_excel('en_high_mp_600K_20210626.xlsx')

#Select the top 100 ITR ranked by xgb model. This is used to compare with literature models
en_high_ITR = ms_ITR[:20]
en_high_ITR.to_excel('en_high_ITR_600K_20210626.xlsx')
en_high_ITR_index = en_high_ITR.index
print('Done!')


# # Results evaluation

# ## High mp, high ITR material systems predicted by Ensemble model

# In[24]:


# high MP high ITR predicted by ensemble model
df_en = ms_ITR[ms_ITR.index.isin(en_high_mp_index)]
df_en = df_en[['fMaterial', 'fFormula', 'fmelt', 'sMaterial', 'sFormula', 'smelt', 'krr_ITR', 'xgb_ITR', 'dnn_ITR', 'en_ITR']]
print(df_en.shape)
df_en[:30]


# ## High ITR prediction by Ensemble model

# In[23]:


indexes = [en_high_ITR_index]
df = ms_ITR[ms_ITR.index.isin(en_high_ITR_index)]
df = df[['fMaterial', 'fFormula', 'fmelt', 'sMaterial', 'sFormula', 'smelt', 'en_ITR']]
df


# In[ ]:





# In[ ]:




